@@ -1,6 +1,8 @@
 from rest_framework import serializers
 
-from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer
+from netbox.api.serializers import NetBoxModelSerializer
+from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
+    NestedWindowsVolumeSerializer
 from netbox_storage.models import Drive, Filesystem, LinuxVolume, WindowsVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
@@ -19,19 +21,24 @@ class FilesystemSerializer(serializers.ModelSerializer):
         )
 
 
-class DriveSerializer(serializers.ModelSerializer):
+class DriveSerializer(NetBoxModelSerializer):
     cluster = NestedClusterSerializer(required=False, allow_null=True)
     virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
+    url = serializers.HyperlinkedIdentityField(view_name="plugins-api:netbox_storage-api:drive-detail")
+    windowsvolumes = NestedWindowsVolumeSerializer(many=True, read_only=True, required=False, default=None,)
 
     class Meta:
         model = Drive
         fields = (
             "id",
+            "url",
+            "display",
             "size",
             "cluster",
             "virtual_machine",
             "identifier",
             "description",
+            "windowsvolumes",
             "created",
             "last_updated",
             "custom_fields",
@@ -56,15 +63,17 @@ class LinuxVolumeSerializer(serializers.ModelSerializer):
         )
 
 
-class WindowsVolumeSerializer(serializers.ModelSerializer):
+class WindowsVolumeSerializer(NetBoxModelSerializer):
+    url = serializers.HyperlinkedIdentityField(view_name="plugins-api:netbox_storage-api:windowsvolume-detail")
     fs = NestedFilesystemSerializer(required=False, allow_null=True)
-    drives = NestedDriveSerializer(required=False, allow_null=True)
+    drives = NestedDriveSerializer(required=False, many=True, read_only=False)
     virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
 
     class Meta:
         model = WindowsVolume
         fields = (
             "id",
+            "url",
             "drive_name",
             "fs",
             "drives",
@@ -74,3 +83,23 @@ class WindowsVolumeSerializer(serializers.ModelSerializer):
             "last_updated",
             "custom_fields",
         )
+
+    def create(self, validated_data):
+        drives = validated_data.pop("drives", None)
+
+        windowsvolume = super().create(validated_data)
+
+        if drives is not None:
+            windowsvolume.drives.set(drives)
+
+        return windowsvolume
+
+    def update(self, instance, validated_data):
+        drives = validated_data.pop("drives", None)
+
+        windowsvolume = super().update(instance, validated_data)
+
+        if drives is not None:
+            windowsvolume.drives.set(drives)
+
+        return windowsvolume
\ No newline at end of file
