@@ -26,7 +26,8 @@ class DriveForm(NetBoxModelForm):
         query_params={
             'site_id': '$site',
             'group_id': '$cluster_group',
-        }
+        },
+        help_text="The Storage Cluster of the drive",
     )
     virtual_machine = DynamicModelChoiceField(
         queryset=VirtualMachine.objects.all(),
